@@ -13,4 +13,4 @@ class Foobar(SplStreamingBatchCommand):
 
 
 if __name__ == '__main__':
-    run(Foobar, sys.argv, sys.stdin.buffer, sys.stdout.buffer)
\ No newline at end of file
+    run(Foobar, sys.argv, sys.stdin.buffer, sys.__stdout__.buffer)
\ No newline at end of file
